****************************************************
*.SUBCKT EL152-pentode 1 2 3 4 ; A G2 G1 C;
.SUBCKT GU50PP 1 2 3 4 ; A G2 G1 C;
*      Extract V3.000
* Model created: 23-Oct-2020
*
* Curves traced and Model developed by Alejandro Moglia
* (c) 2020 by Bartola Ltd. UK 
* For DIY Audio Use Only
* www.bartola.co.uk/valves email: valves@bartola.co.uk
*
X1 1 2 3 4 PenthodeD  MU=  5.4 EX=1.390 kG1= 707.4 KP=  32.3 kVB =  5122.1 kG2=46214.5
+ Ookg1mOokG2=.14E-02 Aokg1=.45E-06 alkg1palskg2=.14E-02 be=   .07 als= 50.58 RGI=2000
+ CCG1=10.0P  CCG2 = 0.0p CPG1 = 0.11p CG1G2 = 0.0p CCP=14.5P  ;
.ENDS GU50PP

****************************************************

.SUBCKT PenthodeD 1 2 3 4; A G2 G1 C
*
* NOTE: LOG(x) is base e LOG or natural logarithm.
* For some Spice versions, e.g. MicroCap, this has to be changed to LN(x).
*
RE1  7 0  1MEG    ; DUMMY SO NODE 7 HAS 2 CONNECTIONS
E1 7 0 VALUE=
+{V(2,4)/KP*LOG(1+EXP(KP*(1/MU+V(3,4)/SQRT(KVB+V(2,4)*V(2,4)))))}
E2   8 0 VALUE = {Ookg1mOokG2 + Aokg1*V(1,4) - alkg1palskg2/(1 + be*V(1,4))}
G1   1 4  VALUE = {0.5*(PWR(V(7),EX)+PWRS(V(7),EX))*V(8)}
G2   2 4 VALUE = {0.5*(PWR(V(7),EX)+PWRS(V(7),EX))/KG2 * (1+ als/(1+be*V(1,4)))}

RCP  1 4  1G      ; FOR CONVERGENCE A  - C
C1   3 4  {CCG1}   ; CATHODE-GRID 1 C  - G1
C4   2 4  {CCG2}   ; CATHODE-GRID 2 C  - G2
C5   2 3  {CG1G2}   ; GRID 1 -GRID 2 G1  - G2
C2   1 3  {CPG1}  ; GRID 1-PLATE G1 - A
C3   1 4  {CCP}   ; CATHODE-PLATE A  - C
R1   3 5  {RGI}   ; FOR GRID CURRENT G1 - 5
D3   5 4  DX      ; FOR GRID CURRENT 5  - C
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N)
.ENDS PenthodeD


.SUBCKT GU50-PP  1 3 4 2 ; P(A) G1 C G2 (Pentode)  21-Nov-2001 
+ PARAMS: MU= 73.53  EX= 1.150  KG1= 194.7  KP= 13.28   KG2= 4500
+ KVB=  30.3  VCT=  0.00  RGI=2k
+ CCG=14P  CPG=0.1P CCP=9.2P
RE1  7 0  1MEG    
E1   7 0  VALUE=  ; E1 BREAKS UP LONG EQUATION FOR G1.
+{V(4,3)/KP*LOG(1+EXP((1/MU+V(2,3)/V(4,3))*KP))}
G1   1 3  VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/KG1*ATAN(V(1,3)/KVB)}
G2   4 3  VALUE={(EXP(EX*(LOG((V(4,3)/MU)+V(2,3)))))/KG2}
RCP  1 3  1G      ; FOR CONVERGENCE
C1   2 3  {CCG}   ; CATHODE-GRID 1
C2   1 2  {CPG}   ; GRID 1-PLATE
C3   1 3  {CCP}   ; CATHODE-PLATE
R1   2 5  {RGI}   ; FOR GRID CURRENT
D3   5 3  DX      ; FOR GRID CURRENT
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N)
.ENDS GU50-PP


* Generic pentode model: GU50PP
* Copyright 2003--2008 by Ayumi Nakabayashi, All rights reserved.
* Version 3.10, Generated on Mon Oct 07 15:38:35 2013
*               Plate
*               | Screen Grid
*               | | Control Grid
*               | | | Cathode
*               | | | |
.SUBCKT GU50_PP A S G K
.PARAM X1=0.99999999 X2=0.095744324 X3=-0.93076058
.PARAM X4=0.61709081 X5=3.9992887 X6=2.4307606
.PARAM X7=0.001292662 X8=6.4808755 X9=0.00082905208
.PARAM Y1=0.00064633102 Y2=0.957887127 Y3=0.042112873
.PARAM Y4=0.00095677822 EA=4395.2
BK IK 0 V=U(V(G,K)+X1)*X7*URAMP(V(G,K)+X1+URAMP(V(S,K))/X8)^1.5+(1-U(V(G,K)+X1))*X9*(X2*URAMP(V(S,K)))^X3*(X4*URAMP(V(G,K)+X1+URAMP(V(S,K))/X5))^X6
BL IL 0 V=(V(IK)-Y1*URAMP(V(G,K))^1.5*(URAMP(V(G,K))/(URAMP(V(A,K))+URAMP(V(G,K)))*1.2+.4))*(1-.4*(EXP(-URAMP(V(A,K))/URAMP(V(S,K))*15)-EXP(-15)))
BM IM 0 V=V(IL)*(URAMP(V(A,K))+EA)/(URAMP(V(S,K))+EA)-URAMP(V(IL)*(URAMP(V(A,K))+EA)/(URAMP(V(S,K))+EA)-(Y4*(URAMP(V(A,K))+URAMP(URAMP(V(S,K))-URAMP(V(A,K))))^1.5))
BA A K I=URAMP(Y4*URAMP(V(A,K))^1.5-URAMP(Y4*URAMP(V(A,K))^1.5-V(IM)+V(IL)*(Y2*(1-URAMP(V(A,K))/(URAMP(V(A,K))+10))^1.5+Y3)))+1E-10*V(A,K)
BS S K I=URAMP(V(IM)-URAMP(Y4*URAMP(V(A,K))^1.5-URAMP(Y4*URAMP(V(A,K))^1.5-V(IM)+V(IL)*(Y2*(1-URAMP(V(A,K))/(URAMP(V(A,K))+10))^1.5+Y3))))
BG G K I=Y1*URAMP(V(G,K))^1.5*(URAMP(V(G,K))/(URAMP(V(A,K))+URAMP(V(G,K)))*1.2+.4)
* CAPS
CGA G A 0.1p
CGK G K 0.6p
CGS G S 0.4p
CAK A K 10p
.ENDS GU50_PP
*